[llvm-commits] CVS: llvm/lib/VMCore/Pass.cpp PassManagerT.h

Chris Lattner lattner at cs.uiuc.edu
Mon Oct 21 15:01:05 PDT 2002


Changes in directory llvm/lib/VMCore:

Pass.cpp updated: 1.39 -> 1.40
PassManagerT.h updated: 1.33 -> 1.34

---
Log message:

  - Rename AnalysisUsage::preservesAll to getPreservesAll & preservesCFG to
    setPreservesCFG to be less confusing.


---
Diffs of the changes:

Index: llvm/lib/VMCore/PassManagerT.h
diff -u llvm/lib/VMCore/PassManagerT.h:1.33 llvm/lib/VMCore/PassManagerT.h:1.34
--- llvm/lib/VMCore/PassManagerT.h:1.33	Tue Oct  1 15:12:06 2002
+++ llvm/lib/VMCore/PassManagerT.h	Mon Oct 21 15:00:28 2002
@@ -252,7 +252,7 @@
 
 
       // Erase all analyses not in the preserved set...
-      if (!AnUsage.preservesAll()) {
+      if (!AnUsage.getPreservesAll()) {
         const std::vector<AnalysisID> &PreservedSet = AnUsage.getPreservedSet();
         for (std::map<AnalysisID, Pass*>::iterator I = CurrentAnalyses.begin(),
                E = CurrentAnalyses.end(); I != E; )
@@ -472,7 +472,7 @@
       markPassUsed(*I, P);     // Mark *I as used by P
 
     // Erase all analyses not in the preserved set...
-    if (!AnUsage.preservesAll()) {
+    if (!AnUsage.getPreservesAll()) {
       const std::vector<AnalysisID> &PreservedSet = AnUsage.getPreservedSet();
       for (std::map<AnalysisID, Pass*>::iterator I = CurrentAnalyses.begin(),
              E = CurrentAnalyses.end(); I != E; ) {





More information about the llvm-commits mailing list
Index: llvm/lib/VMCore/Pass.cpp
diff -u llvm/lib/VMCore/Pass.cpp:1.39 llvm/lib/VMCore/Pass.cpp:1.40
--- llvm/lib/VMCore/Pass.cpp:1.39	Tue Oct  1 14:54:07 2002
+++ llvm/lib/VMCore/Pass.cpp	Mon Oct 21 15:00:28 2002
@@ -43,7 +43,7 @@
 //   AnalysisUsage Class Implementation
 //
 
 // preservesCFG - This function should be called to by the pass, iff they do
 // not:
 //
 //  1. Add or remove basic blocks from the function
@@ -52,7 +52,7 @@
 // This function annotates the AnalysisUsage info object to say that analyses
 // that only depend on the CFG are preserved by this pass.
 //
-void AnalysisUsage::preservesCFG() {
+void AnalysisUsage::setPreservesCFG() {
   // Since this transformation doesn't modify the CFG, it preserves all analyses
   // that only depend on the CFG (like dominators, loop info, etc...)
   //
@@ -43,7 +43,7 @@
 //
 
-// preservesCFG - This function should be called to by the pass, iff they do
+// setPreservesCFG - This function should be called to by the pass, iff they do
 // not:
 //

